@@ -1,24 +1,7 @@
-# The MIT License (MIT)
+# SPDX-FileCopyrightText: 2019 Brent Rubell for Adafruit Industries
 #
-# Copyright (c) 2019 Brent Rubell for Adafruit Industries
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+# SPDX-License-Identifier: MIT
+
 """
 `adafruit_hue`
 ================================================================================
@@ -186,8 +169,7 @@ class Bridge:
         return resp
 
     def get_lights(self):
-        """Returns all the light resources available for a bridge.
-        """
+        """Returns all the light resources available for a bridge."""
         resp = self._get(self._username_url + "/lights")
         return resp
 
@@ -218,8 +200,7 @@ class Bridge:
         return resp
 
     def get_groups(self):
-        """Returns all the light groups available for a bridge.
-        """
+        """Returns all the light groups available for a bridge."""
         resp = self._get(self._username_url + "/groups")
         return resp
 
@@ -232,8 +213,7 @@ class Bridge:
         self.set_group(group_id, scene=scene_id)
 
     def get_scenes(self):
-        """Returns a list of all scenes currently stored in the bridge.
-        """
+        """Returns a list of all scenes currently stored in the bridge."""
         resp = self._get(self._username_url + "/scenes")
         return resp
 
